#region Copyright Syncfusion Inc. 2001 - 2006
//
//  Copyright Syncfusion Inc. 2001 - 2006. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Shared;

namespace EssentialPDFSamples
{
	/// <summary>
	/// Summary description for WebForm1.
	/// </summary>
	public class WebForm1 : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label Label1;
		protected System.Web.UI.WebControls.Button Button1;
		protected System.Web.UI.WebControls.CheckBox CheckBox1;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Button1.Click += new System.EventHandler(this.Button1_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void Button1_Click(object sender, System.EventArgs e)
		{
			//Create a new PDF Document. This object represents the whole PDF document.
			//This document had One page by default. Additional pages have to be added.
			PDFDocument pdfDoc = new PDFDocument();

			//This event is called when a new page is created.
			pdfDoc.PageCreated +=new PageCreatedEventHandler(pdfDoc_PageCreated);
		
			
			//Create some pages.
			int npage=5;
			for(int i=0; i<npage;i++)
			{
				pdfDoc.CreatePage();
			}

			//Stream the output to the browser.	
			if(this.CheckBox1.Checked)
			{
				pdfDoc.Save("Sample.pdf",Response,HttpReadType.Open);
			}
			else
			{
				pdfDoc.Save("Sample.pdf",Response,HttpReadType.Save);
			}
		}

		private PDFTemplateArea AddHeader( PDFDocument doc, string title, string description )
		{
			if( doc == null )
			{
				throw new ArgumentNullException( "doc" );
			}

			if( title == null )
			{
				throw new ArgumentNullException( "title" );
			}

			const int offset = 10;

			// Add the header   
			PDFTemplateArea  header = doc.Templates.Add(doc.LastPage.DrawingWidth,60);
			//Add the font that will be used in the header
			IPDFFont font = doc.Fonts.Add( FontBaseFamily.HelveticaBold );
			//Define font properties for the header.
			font.Size = 24;
			//Just to make sure that we have enough space in the header.
			float doubleHeight = font.Height * 2;
			Color activeColor = Color.FromArgb( 44, 71, 120 );

			//Add Logo Image
			//IPDFGraphicState is used for setting properties of all drawing objects.
			IPDFGraphicState props = doc.CreateGraphicState();
			SizeF imageSize = new SizeF( 110f, 35f );
			//Locating the logo on the right corner of the Drawing Surface
			PointF imageLocation = new PointF( doc.LastPage.DrawingWidth - imageSize.Width-20, 15 );      
			props.Padding = new PDFPadding( offset, offset, 0, 0 );
			
			
			//Draw the image in the Header.
			header.Graphics.DrawImage(imageLocation, Server.MapPath (@"Data\logo.jpg"),imageSize, props );

			//Add Title Tab
			props = doc.CreateGraphicState();
			props.TextAlignment = TextAlignment.Center;
			props.ForeColor = activeColor;
			props.Scale( 0.8f, 0.7f );
			props.Padding = new PDFPadding( offset * 2, 0, ( int )imageSize.Width, 0 );
			header.Graphics.DrawMultiText( offset, 5, doc.LastPage.DrawingWidth, font.Height, title, font, props );

			SizeF headerSize;
			//Add description tag
			if( description != null && description.Length > 0 )
			{
				headerSize = header.Size;
				font = doc.Fonts.Add( FontBaseFamily.HelveticaOblique );
				font.Size = 8;
				props = doc.CreateGraphicState();
				props.TextAlignment = TextAlignment.Left;
				props.Padding = new PDFPadding( offset, 0, 0, 0 );
				props.ForeColor = Color.Gray;
				header.Graphics.DrawMultiText( 10, headerSize.Height-15,
					doc.LastPage.DrawingWidth, font.Height, description, font, props );
			}

			//Add the border effect.
			headerSize = header.Size;
			headerSize.Height += 10;
			activeColor = Color.FromArgb( 139, 164, 204 );
			props = doc.CreateGraphicState();
			props.ForeColor = activeColor;
			header.Graphics.DrawLine( 0, 0, headerSize.Width-10, 0 );
			header.Graphics.DrawLine( 0, headerSize.Height-10, headerSize.Width-10, headerSize.Height );
			header.Graphics.DrawLine( 0, 0, 0, headerSize.Height );
			header.Graphics.DrawLine( headerSize.Width-10, 0, headerSize.Width-10, headerSize.Height );
			
			props = doc.CreateGraphicState();
			props.LineWidth = 2;
			props.ForeColor = activeColor;
			header.Graphics.DrawLine( 0, 2, headerSize.Width-10, 2, props );
			header.Graphics.DrawLine( 0, headerSize.Height - 12, headerSize.Width-10, headerSize.Height -12, props );

			header.Graphics.DrawLine( 0, 5, headerSize.Width-10, 5 );
			header.Graphics.DrawLine( 0, headerSize.Height - 15, headerSize.Width-10, headerSize.Height - 15 );

			return header;
			
			
		}

		private void pdfDoc_PageCreated(object sender, PageCreatedEventArgs arg)
		{
			arg.Page.Graphics.DrawRectangle(new RectangleF(PointF.Empty,new SizeF(arg.Page.DrawingWidth-10,arg.Page.DrawingHeight-10)));
			
			PDFTemplateArea  header= AddHeader(arg.Page.Document,"Headers and Footer on Page "+arg.Index.ToString(),"Northwind Customers");
			
			// Use the following code to draw text at the particular location.
			// header.Graphics.DrawText(10,10,"Page"+arg.Index.ToString(),arg.Page.Document.Fonts.Add(FontBaseFamily.Courier));
			
			
			arg.Page.Header = header;
		}

	}
}
